==> mediawiki-1.16.0.tbz: www/mediawiki/languages/messages/MessagesOr.php <==
<?php
/** Oriya (ଓଡ଼ିଆ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
 */

$digitTransformTable = array(
	'0' => '୦', # &#x0b66;
	'1' => '୧', # &#x0b67;
	'2' => '୨', # &#x0b68;
	'3' => '୩', # &#x0b69;
	'4' => '୪', # &#x0b6a;
	'5' => '୫', # &#x0b6b;
	'6' => '୬', # &#x0b6c;
	'7' => '୭', # &#x0b6d;
	'8' => '୮', # &#x0b6e;
	'9' => '୯', # &#x0b6f;
);

$messages = array(
'mytalk'     => 'ମୋ କଥା',
'navigation' => 'ଦିଗ୍ଦର୍ଶକ',

'help'             => 'ସାହାଜ୍ଯ',
'search'           => 'ସନ୍ଧାନ',
'searchbutton'     => 'ସନ୍ଧାନ',
'history_short'    => 'ଇତିହାସ',
'protect'          => 'ସୁରଖ୍ଯା',
'talk'             => 'ଆଲୋଚନା',
'toolbox'          => 'ଜନ୍ତ୍ର ବାକ୍ସ',
'jumptonavigation' => 'ଦିଗ୍ଦର୍ଶକ',
'jumptosearch'     => 'ସନ୍ଧାନ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage'             => 'ପ୍ରଧାନ ପ୍ରୁଷ୍ଟ୍ଆ',
'mainpage-description' => 'ପ୍ରଧାନ ପ୍ରୁଷ୍ଟ୍ଆ',

'viewsourcelink' => 'େଦଖ ଉର୍ସ',

# General errors
'viewsource' => 'େଦଖ ଉର୍ସ',

# Edit pages
'summary'  => 'ସାରକଥା:',
'showdiff' => 'େଦଖାଅ ପରିବର୍ତନଗୁଡିକ',

# Preferences page
'searchresultshead' => 'ସନ୍ଧାନ',

# Recent changes linked
'recentchangeslinked'         => 'ସମ୍ବଧ୍ହିତ ପରିବର୍ତନ',
'recentchangeslinked-feed'    => 'ସମ୍ବଧ୍ହିତ ପରିବର୍ତନ',
'recentchangeslinked-toolbox' => 'ସମ୍ବଧ୍ହିତ ପରିବର୍ତନ',

# Upload
'filedesc'          => 'ସାରକଥା',
'fileuploadsummary' => 'ସାରକଥା:',

# Special:LinkSearch
'linksearch-ok' => 'ସନ୍ଧାନ',

# Watchlist
'watch' => 'େଦଖ',

# Undelete
'undelete-search-submit' => 'ସନ୍ଧାନ',

# Contributions
'contributions' => 'ବ୍ଯବହରକାରୀନ୍କ ଅନୁଦାନ',

'sp-contributions-submit' => 'ସନ୍ଧାନ',

# Block/unblock
'ipblocklist-submit' => 'ସନ୍ଧାନ',

# Tooltip help for the actions
'tooltip-p-logo' => 'ପ୍ରଧାନ ପ୍ରୁଷ୍ଟ୍ଆ',

# Special:NewFiles
'ilsubmit' => 'ସନ୍ଧାନ',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'ସନ୍ଧାନ',

# Special:SpecialPages
'specialpages' => 'ସ୍ବତନ୍ତ୍ର',

);

==> mediawiki-1.16.2.tbz: www/mediawiki/languages/messages/MessagesOr.php <==
<?php
/** Oriya (ଓଡ଼ିଆ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
 */

$digitTransformTable = array(
	'0' => '୦', # &#x0b66;
	'1' => '୧', # &#x0b67;
	'2' => '୨', # &#x0b68;
	'3' => '୩', # &#x0b69;
	'4' => '୪', # &#x0b6a;
	'5' => '୫', # &#x0b6b;
	'6' => '୬', # &#x0b6c;
	'7' => '୭', # &#x0b6d;
	'8' => '୮', # &#x0b6e;
	'9' => '୯', # &#x0b6f;
);

$messages = array(
'mytalk'     => 'ମୋ କଥା',
'navigation' => 'ଦିଗ୍ଦର୍ଶକ',

'help'             => 'ସାହାଜ୍ଯ',
'search'           => 'ସନ୍ଧାନ',
'searchbutton'     => 'ସନ୍ଧାନ',
'history_short'    => 'ଇତିହାସ',
'protect'          => 'ସୁରଖ୍ଯା',
'talk'             => 'ଆଲୋଚନା',
'toolbox'          => 'ଜନ୍ତ୍ର ବାକ୍ସ',
'jumptonavigation' => 'ଦିଗ୍ଦର୍ଶକ',
'jumptosearch'     => 'ସନ୍ଧାନ',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage'             => 'ପ୍ରଧାନ ପ୍ରୁଷ୍ଟ୍ଆ',
'mainpage-description' => 'ପ୍ରଧାନ ପ୍ରୁଷ୍ଟ୍ଆ',

'viewsourcelink' => 'େଦଖ ଉର୍ସ',

# General errors
'viewsource' => 'େଦଖ ଉର୍ସ',

# Edit pages
'summary'  => 'ସାରକଥା:',
'showdiff' => 'େଦଖାଅ ପରିବର୍ତନଗୁଡିକ',

# Preferences page
'searchresultshead' => 'ସନ୍ଧାନ',

# Recent changes linked
'recentchangeslinked'         => 'ସମ୍ବଧ୍ହିତ ପରିବର୍ତନ',
'recentchangeslinked-feed'    => 'ସମ୍ବଧ୍ହିତ ପରିବର୍ତନ',
'recentchangeslinked-toolbox' => 'ସମ୍ବଧ୍ହିତ ପରିବର୍ତନ',

# Upload
'filedesc'          => 'ସାରକଥା',
'fileuploadsummary' => 'ସାରକଥା:',

# Special:LinkSearch
'linksearch-ok' => 'ସନ୍ଧାନ',

# Watchlist
'watch' => 'େଦଖ',

# Undelete
'undelete-search-submit' => 'ସନ୍ଧାନ',

# Contributions
'contributions' => 'ବ୍ଯବହରକାରୀନ୍କ ଅନୁଦାନ',

'sp-contributions-submit' => 'ସନ୍ଧାନ',

# Block/unblock
'ipblocklist-submit' => 'ସନ୍ଧାନ',

# Tooltip help for the actions
'tooltip-p-logo'                 => 'ପ୍ରଧାନ ପ୍ରୁଷ୍ଟ୍ଆ',
'tooltip-n-mainpage'             => 'ପ୍ରଧାନ ପ୍ରୁଷ୍ଟ୍ଆ',
'tooltip-n-mainpage-description' => 'ପ୍ରଧାନ ପ୍ରୁଷ୍ଟ୍ଆ',

# Special:NewFiles
'ilsubmit' => 'ସନ୍ଧାନ',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'ସନ୍ଧାନ',

# Special:SpecialPages
'specialpages' => 'ସ୍ବତନ୍ତ୍ର',

);
